@@ -46,6 +46,7 @@ struct _SnapdSnap
     gchar *id;
     GDateTime *install_date;
     gint64 installed_size;
+    gboolean jailmode;
     gchar *name;
     GPtrArray *prices;
     gboolean private;
@@ -53,6 +54,7 @@ struct _SnapdSnap
     GPtrArray *screenshots;
     SnapdSnapStatus status;
     gchar *summary;
+    gchar *tracking_channel;
     gboolean trymode;
     SnapdSnapType snap_type;
     gchar *version;
@@ -71,6 +73,7 @@ enum
     PROP_ID,
     PROP_INSTALL_DATE,
     PROP_INSTALLED_SIZE,
+    PROP_JAILMODE,
     PROP_NAME,
     PROP_PRICES,
     PROP_PRIVATE,
@@ -81,6 +84,7 @@ enum
     PROP_TRYMODE,
     PROP_SNAP_TYPE,
     PROP_VERSION,
+    PROP_TRACKING_CHANNEL,  
     PROP_LAST
 };
 
@@ -97,7 +101,7 @@ G_DEFINE_TYPE (SnapdSnap, snapd_snap, G_TYPE_OBJECT)
 GPtrArray *
 snapd_snap_get_apps (SnapdSnap *snap)
 {
-    g_return_val_if_fail (SNAPD_IS_SNAP (snap), FALSE);
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
     return snap->apps;
 }
 
@@ -228,7 +232,7 @@ snapd_snap_get_id (SnapdSnap *snap)
  * 
  * Get the date this snap was installed or %NULL if unknown.
  *
- * Returns: (allow-none): a #GDateTime or %NULL.
+ * Returns: (transfer none) (allow-none): a #GDateTime or %NULL.
  */
 GDateTime *
 snapd_snap_get_install_date (SnapdSnap *snap)
@@ -252,6 +256,21 @@ snapd_snap_get_installed_size (SnapdSnap *snap)
     return snap->installed_size;
 }
 
+/**
+ * snapd_snap_get_jailmode:
+ * @snap: a #SnapdSnap.
+ *
+ * Get if this snap is running in enforced confinement (jail) mode.
+ *
+ * Returns: %TRUE if this snap is running in jailmode.
+ */
+gboolean
+snapd_snap_get_jailmode (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), FALSE);
+    return snap->jailmode;
+}
+
 /**
  * snapd_snap_get_name:
  * @snap: a #SnapdSnap.
@@ -274,12 +293,12 @@ snapd_snap_get_name (SnapdSnap *snap)
  *
  * Get the prices that this snap can be purchased at.
  *
- * Returns: (transfer none) (element-type SnapdPrice): an array of prices.
+ * Returns: (transfer none) (element-type SnapdPrice): an array of #SnapdPrice.
  */
 GPtrArray *
 snapd_snap_get_prices (SnapdSnap *snap)
 {
-    g_return_val_if_fail (SNAPD_IS_SNAP (snap), FALSE);
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
     return snap->prices;
 }
 
@@ -320,7 +339,7 @@ snapd_snap_get_revision (SnapdSnap *snap)
  *
  * Get the screenshots that are available for this snap.
  *
- * Returns: (transfer none) (element-type SnapdScreenshot): an array of screenshots.
+ * Returns: (transfer none) (element-type SnapdScreenshot): an array of #SnapdScreenshot.
  */
 GPtrArray *
 snapd_snap_get_screenshots (SnapdSnap *snap)
@@ -374,6 +393,21 @@ snapd_snap_get_summary (SnapdSnap *snap)
     return snap->summary;
 }
 
+/**
+ * snapd_snap_get_tracking_channel:
+ * @snap: a #SnapdSnap.
+ *
+ * Get the channel that updates will be installed from, e.g. "stable".
+ *
+ * Returns: a channel name.
+ */
+const gchar *
+snapd_snap_get_tracking_channel (SnapdSnap *snap)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (snap), NULL);
+    return snap->tracking_channel;
+}
+
 /**
  * snapd_snap_get_trymode:
  * @snap: a #SnapdSnap.
@@ -454,6 +488,9 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
     case PROP_INSTALLED_SIZE:
         snap->installed_size = g_value_get_int64 (value);
         break;
+    case PROP_JAILMODE:
+        snap->jailmode = g_value_get_boolean (value);
+        break;
     case PROP_NAME:
         g_free (snap->name);
         snap->name = g_strdup (g_value_get_string (value));
@@ -485,6 +522,10 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
         g_free (snap->summary);
         snap->summary = g_strdup (g_value_get_string (value));
         break;
+    case PROP_TRACKING_CHANNEL:
+        g_free (snap->tracking_channel);
+        snap->tracking_channel = g_strdup (g_value_get_string (value));
+        break;
     case PROP_TRYMODE:
         snap->trymode = g_value_get_boolean (value);
         break;
@@ -537,6 +578,9 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_INSTALLED_SIZE:
         g_value_set_int64 (value, snap->installed_size);
         break;
+    case PROP_JAILMODE:
+        g_value_set_boolean (value, snap->jailmode);
+        break;
     case PROP_NAME:
         g_value_set_string (value, snap->name);
         break;
@@ -561,6 +605,9 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_SUMMARY:
         g_value_set_string (value, snap->summary);
         break;
+    case PROP_TRACKING_CHANNEL:
+        g_value_set_string (value, snap->tracking_channel);
+        break;
     case PROP_TRYMODE:
         g_value_set_boolean (value, snap->trymode);
         break;
@@ -593,6 +640,7 @@ snapd_snap_finalize (GObject *object)
     if (snap->screenshots != NULL)
         g_clear_pointer (&snap->screenshots, g_ptr_array_unref);
     g_clear_pointer (&snap->summary, g_free);
+    g_clear_pointer (&snap->tracking_channel, g_free);  
     g_clear_pointer (&snap->version, g_free);
 }
 
@@ -616,7 +664,7 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                      PROP_CHANEL,
                                      g_param_spec_string ("channel",
                                                           "channel",
-                                                          "Channel the snap is currently tracking",
+                                                          "Channel the snap is from",
                                                           NULL,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
@@ -682,6 +730,13 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                          "Installed size in bytes",
                                                          G_MININT64, G_MAXINT64, 0,
                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_JAILMODE,
+                                     g_param_spec_boolean ("jailmode",
+                                                           "jailmode",
+                                                           "TRUE if the snap is currently installed in jailmode",
+                                                           FALSE,
+                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_NAME,
                                      g_param_spec_string ("name",
@@ -731,6 +786,13 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                           "One line description",
                                                           NULL,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_TRACKING_CHANNEL,
+                                     g_param_spec_string ("tracking-channel",
+                                                          "tracking-channel",
+                                                          "Channel the snap is currently tracking",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_TRYMODE,
                                      g_param_spec_boolean ("trymode",
