@@ -34,6 +34,7 @@ struct _SnapdSnapClass
  * @SNAPD_CONFINEMENT_UNKNOWN: the confinement of the snap is unknown.
  * @SNAPD_CONFINEMENT_STRICT: the snap is using confinement.
  * @SNAPD_CONFINEMENT_DEVMODE: the snap is in dev mode (i.e. unconfined).
+ * @SNAPD_CONFINEMENT_CLASSIC: the snap is using classic confinement.
  *
  * Confinment used by a snap.
  */
@@ -41,7 +42,8 @@ typedef enum
 {
     SNAPD_CONFINEMENT_UNKNOWN,
     SNAPD_CONFINEMENT_STRICT,
-    SNAPD_CONFINEMENT_DEVMODE
+    SNAPD_CONFINEMENT_DEVMODE,
+    SNAPD_CONFINEMENT_CLASSIC
 } SnapdConfinement;
 
 /**
@@ -82,49 +84,51 @@ typedef enum
     SNAPD_SNAP_STATUS_ACTIVE
 } SnapdSnapStatus;
 
-GPtrArray        *snapd_snap_get_apps           (SnapdSnap *snap);
+GPtrArray        *snapd_snap_get_apps             (SnapdSnap *snap);
 
-const gchar      *snapd_snap_get_channel        (SnapdSnap *snap);
+const gchar      *snapd_snap_get_channel          (SnapdSnap *snap);
 
-SnapdConfinement  snapd_snap_get_confinement    (SnapdSnap *snap);
+SnapdConfinement  snapd_snap_get_confinement      (SnapdSnap *snap);
 
-const gchar      *snapd_snap_get_description    (SnapdSnap *snap);
+const gchar      *snapd_snap_get_description      (SnapdSnap *snap);
 
-const gchar      *snapd_snap_get_developer      (SnapdSnap *snap);
+const gchar      *snapd_snap_get_developer        (SnapdSnap *snap);
 
-gboolean          snapd_snap_get_devmode        (SnapdSnap *snap);
+gboolean          snapd_snap_get_devmode          (SnapdSnap *snap);
 
-gint64            snapd_snap_get_download_size  (SnapdSnap *snap);
+gint64            snapd_snap_get_download_size    (SnapdSnap *snap);
 
-const gchar      *snapd_snap_get_icon           (SnapdSnap *snap);
+const gchar      *snapd_snap_get_icon             (SnapdSnap *snap);
 
-const gchar      *snapd_snap_get_id             (SnapdSnap *snap);
+const gchar      *snapd_snap_get_id               (SnapdSnap *snap);
 
-GDateTime        *snapd_snap_get_install_date   (SnapdSnap *snap);
+GDateTime        *snapd_snap_get_install_date     (SnapdSnap *snap);
 
-gint64            snapd_snap_get_installed_size (SnapdSnap *snap);
+gint64            snapd_snap_get_installed_size   (SnapdSnap *snap);
 
-const gchar      *snapd_snap_get_name           (SnapdSnap *snap);
+gboolean          snapd_snap_get_jailmode          (SnapdSnap *snap);
 
-#ifdef SNAPD_BUY_SUPPORT
-GPtrArray        *snapd_snap_get_prices         (SnapdSnap *snap);
-#endif
+const gchar      *snapd_snap_get_name             (SnapdSnap *snap);
 
-gboolean          snapd_snap_get_private        (SnapdSnap *snap);
+GPtrArray        *snapd_snap_get_prices           (SnapdSnap *snap);
 
-const gchar      *snapd_snap_get_revision       (SnapdSnap *snap);
+gboolean          snapd_snap_get_private          (SnapdSnap *snap);
 
-GPtrArray        *snapd_snap_get_screenshots    (SnapdSnap *snap);
+const gchar      *snapd_snap_get_revision         (SnapdSnap *snap);
 
-SnapdSnapType     snapd_snap_get_snap_type      (SnapdSnap *snap);
+GPtrArray        *snapd_snap_get_screenshots      (SnapdSnap *snap);
 
-SnapdSnapStatus   snapd_snap_get_status         (SnapdSnap *snap);
+SnapdSnapType     snapd_snap_get_snap_type        (SnapdSnap *snap);
 
-const gchar      *snapd_snap_get_summary        (SnapdSnap *snap);
+SnapdSnapStatus   snapd_snap_get_status           (SnapdSnap *snap);
 
-gboolean          snapd_snap_get_trymode        (SnapdSnap *snap);
+const gchar      *snapd_snap_get_summary          (SnapdSnap *snap);
 
-const gchar      *snapd_snap_get_version        (SnapdSnap *snap);
+const gchar      *snapd_snap_get_tracking_channel (SnapdSnap *snap);
+
+gboolean          snapd_snap_get_trymode          (SnapdSnap *snap);
+
+const gchar      *snapd_snap_get_version          (SnapdSnap *snap);
 
 G_END_DECLS
 
