@@ -32,9 +32,11 @@ struct _SnapdSystemInformation
     GObject parent_instance;
 
     gboolean on_classic;
+    gboolean managed;  
     gchar *os_id;
     gchar *os_version;
     gchar *series;
+    gchar *store;  
     gchar *version;
 };
 
@@ -44,12 +46,29 @@ enum
     PROP_OS_ID,
     PROP_OS_VERSION,
     PROP_SERIES,
+    PROP_STORE,  
     PROP_VERSION,
+    PROP_MANAGED,  
     PROP_LAST
 };
 
 G_DEFINE_TYPE (SnapdSystemInformation, snapd_system_information, G_TYPE_OBJECT)
 
+/**
+ * snapd_system_information_get_managed:
+ * @system_information: a #SnapdSystemInformation.
+ *
+ * Get if snapd is running on a managed system.
+ *
+ * Returns: %TRUE if running on a managed system.
+ */
+gboolean
+snapd_system_information_get_managed (SnapdSystemInformation *system_information)
+{
+    g_return_val_if_fail (SNAPD_IS_SYSTEM_INFORMATION (system_information), FALSE);
+    return system_information->managed;
+}
+
 /**
  * snapd_system_information_get_on_classic:
  * @system_information: a #SnapdSystemInformation.
@@ -110,6 +129,21 @@ snapd_system_information_get_series (SnapdSystemInformation *system_information)
     return system_information->series;
 }
 
+/**
+ * snapd_system_information_get_store:
+ * @system_information: a #SnapdSystemInformation.
+ *
+ * Get the store being used by snapd, e.g. "Ubuntu"
+ *
+ * Returns: (allow-none): a store id or %NULL.
+ */
+const gchar *
+snapd_system_information_get_store (SnapdSystemInformation *system_information)
+{
+    g_return_val_if_fail (SNAPD_IS_SYSTEM_INFORMATION (system_information), NULL);
+    return system_information->store;
+}
+
 /**
  * snapd_system_information_get_version:
  * @system_information: a #SnapdSystemInformation.
@@ -131,6 +165,9 @@ snapd_system_information_set_property (GObject *object, guint prop_id, const GVa
     SnapdSystemInformation *system_information = SNAPD_SYSTEM_INFORMATION (object);
 
     switch (prop_id) {
+    case PROP_MANAGED:
+        system_information->managed = g_value_get_boolean (value);
+        break;
     case PROP_ON_CLASSIC:
         system_information->on_classic = g_value_get_boolean (value);
         break;
@@ -146,6 +183,10 @@ snapd_system_information_set_property (GObject *object, guint prop_id, const GVa
         g_free (system_information->series);      
         system_information->series = g_strdup (g_value_get_string (value));
         break;
+    case PROP_STORE:
+        g_free (system_information->store);
+        system_information->store = g_strdup (g_value_get_string (value));
+        break;
     case PROP_VERSION:
         g_free (system_information->version);
         system_information->version = g_strdup (g_value_get_string (value));
@@ -162,6 +203,9 @@ snapd_system_information_get_property (GObject *object, guint prop_id, GValue *v
     SnapdSystemInformation *system_information = SNAPD_SYSTEM_INFORMATION (object);
 
     switch (prop_id) {
+    case PROP_MANAGED:
+        g_value_set_boolean (value, system_information->managed);
+        break;
     case PROP_ON_CLASSIC:
         g_value_set_boolean (value, system_information->on_classic);
         break;
@@ -174,6 +218,9 @@ snapd_system_information_get_property (GObject *object, guint prop_id, GValue *v
     case PROP_SERIES:
         g_value_set_string (value, system_information->series);
         break;
+    case PROP_STORE:
+        g_value_set_string (value, system_information->store);
+        break;
     case PROP_VERSION:
         g_value_set_string (value, system_information->version);
         break;
@@ -191,6 +238,7 @@ snapd_system_information_finalize (GObject *object)
     g_clear_pointer (&system_information->os_id, g_free);
     g_clear_pointer (&system_information->os_version, g_free);
     g_clear_pointer (&system_information->series, g_free);
+    g_clear_pointer (&system_information->store, g_free);  
     g_clear_pointer (&system_information->version, g_free);
 }
 
@@ -202,7 +250,14 @@ snapd_system_information_class_init (SnapdSystemInformationClass *klass)
     gobject_class->set_property = snapd_system_information_set_property;
     gobject_class->get_property = snapd_system_information_get_property; 
     gobject_class->finalize = snapd_system_information_finalize;
-
+ 
+    g_object_class_install_property (gobject_class,
+                                     PROP_MANAGED,
+                                     g_param_spec_boolean ("managed",
+                                                           "managed",
+                                                           "TRUE if snapd managing the system",
+                                                           FALSE,
+                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_ON_CLASSIC,
                                      g_param_spec_boolean ("on-classic",
@@ -231,6 +286,13 @@ snapd_system_information_class_init (SnapdSystemInformationClass *klass)
                                                           "Snappy release series",
                                                           NULL,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_STORE,
+                                     g_param_spec_string ("store",
+                                                          "store",
+                                                          "Snap store",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_VERSION,
                                      g_param_spec_string ("version",
