@@ -28,6 +28,8 @@ struct _SnapdSystemInformationClass
     GObjectClass parent_class;
 };
 
+gboolean     snapd_system_information_get_managed    (SnapdSystemInformation *system_information);
+
 gboolean     snapd_system_information_get_on_classic (SnapdSystemInformation *system_information);
 
 const gchar *snapd_system_information_get_os_id      (SnapdSystemInformation *system_information);
@@ -36,6 +38,8 @@ const gchar *snapd_system_information_get_os_version (SnapdSystemInformation *sy
 
 const gchar *snapd_system_information_get_series     (SnapdSystemInformation *system_information);
 
+const gchar *snapd_system_information_get_store      (SnapdSystemInformation *system_information);
+
 const gchar *snapd_system_information_get_version    (SnapdSystemInformation *system_information);
 
 G_END_DECLS
