@@ -12,14 +12,14 @@
 #include <string.h>
 
 #include "snapd-task.h"
+#include "snapd-change.h"
 
 /**
  * SECTION: snapd-task
  * @short_description: Task progress
  * @include: snapd-glib/snapd-glib.h
  *
- * A #SnapdTask contains information on how a request is progressing. Progress
- * information is returned in a #SnapdProgressCallback.
+ * A #SnapdTask contains information on a task in a #SnapdChange.
  */
 
 /**
@@ -37,7 +37,7 @@ struct _SnapdTask
     gchar *kind;  
     gchar *summary;
     gchar *status;  
-    gboolean ready;
+    gchar *progress_label;
     gint64 progress_done;
     gint64 progress_total;
     GDateTime *spawn_time;
@@ -54,7 +54,8 @@ enum
     PROP_PROGRESS_DONE,
     PROP_PROGRESS_TOTAL,
     PROP_SPAWN_TIME,
-    PROP_READY_TIME,  
+    PROP_READY_TIME,
+    PROP_PROGRESS_LABEL,
     PROP_LAST
 };
  
@@ -71,6 +72,10 @@ G_DEFINE_TYPE (SnapdTask, snapd_task, G_TYPE_OBJECT)
 const gchar *
 snapd_task_get_id (SnapdTask *task)
 {
+    /* Workaround to handle API change in SnapdProgressCallback */
+    if (SNAPD_IS_CHANGE (task))
+        return snapd_change_get_id (SNAPD_CHANGE (task));
+
     g_return_val_if_fail (SNAPD_IS_TASK (task), NULL);
     return task->id;
 }
@@ -86,6 +91,10 @@ snapd_task_get_id (SnapdTask *task)
 const gchar *
 snapd_task_get_kind (SnapdTask *task)
 {
+    /* Workaround to handle API change in SnapdProgressCallback */
+    if (SNAPD_IS_CHANGE (task))
+        return snapd_change_get_kind (SNAPD_CHANGE (task));
+
     g_return_val_if_fail (SNAPD_IS_TASK (task), NULL);
     return task->kind;
 }
@@ -101,6 +110,10 @@ snapd_task_get_kind (SnapdTask *task)
 const gchar *
 snapd_task_get_summary (SnapdTask *task)
 {
+    /* Workaround to handle API change in SnapdProgressCallback */
+    if (SNAPD_IS_CHANGE (task))
+        return snapd_change_get_summary (SNAPD_CHANGE (task));
+
     g_return_val_if_fail (SNAPD_IS_TASK (task), NULL);
     return task->summary;
 }
@@ -116,6 +129,10 @@ snapd_task_get_summary (SnapdTask *task)
 const gchar *
 snapd_task_get_status (SnapdTask *task)
 {
+    /* Workaround to handle API change in SnapdProgressCallback */
+    if (SNAPD_IS_CHANGE (task))
+        return snapd_change_get_status (SNAPD_CHANGE (task));
+
     g_return_val_if_fail (SNAPD_IS_TASK (task), NULL);
     return task->status;
 }
@@ -126,13 +143,37 @@ snapd_task_get_status (SnapdTask *task)
  *
  * Get if this task is completed.
  *
+ * Depcrecated: 1.5: Use snapd_change_get_ready() instead.
+ *
  * Returns: %TRUE if this task is complete.
  */
 gboolean
 snapd_task_get_ready (SnapdTask *task)
 {
-    g_return_val_if_fail (SNAPD_IS_TASK (task), FALSE);
-    return task->ready;
+    /* Workaround to handle API change in SnapdProgressCallback */
+    if (SNAPD_IS_CHANGE (task))
+        return snapd_change_get_ready (SNAPD_CHANGE (task));
+
+    return FALSE;
+}
+
+/**
+ * snapd_task_get_progress_label:
+ * @task: a #SnapdTask.
+ *
+ * Get the the label associated with the progress.
+ *
+ * Returns: a label string.
+ */
+const gchar *
+snapd_task_get_progress_label (SnapdTask *task)
+{
+    /* Workaround to handle API change in SnapdProgressCallback */
+    if (SNAPD_IS_CHANGE (task))
+        return NULL;
+
+    g_return_val_if_fail (SNAPD_IS_TASK (task), NULL);
+    return task->progress_label;
 }
 
 /**
@@ -146,6 +187,10 @@ snapd_task_get_ready (SnapdTask *task)
 gint64
 snapd_task_get_progress_done (SnapdTask *task)
 {
+    /* Workaround to handle API change in SnapdProgressCallback */
+    if (SNAPD_IS_CHANGE (task))
+        return 0;
+
     g_return_val_if_fail (SNAPD_IS_TASK (task), 0);
     return task->progress_done;
 }
@@ -161,6 +206,10 @@ snapd_task_get_progress_done (SnapdTask *task)
 gint64
 snapd_task_get_progress_total (SnapdTask *task)
 {
+    /* Workaround to handle API change in SnapdProgressCallback */
+    if (SNAPD_IS_CHANGE (task))
+        return 0;
+
     g_return_val_if_fail (SNAPD_IS_TASK (task), 0);
     return task->progress_total;
 }
@@ -171,11 +220,15 @@ snapd_task_get_progress_total (SnapdTask *task)
  *
  * Get the time this task started.
  *
- * Returns: a #GDateTime.
+ * Returns: (transfer none): a #GDateTime.
  */
 GDateTime *
 snapd_task_get_spawn_time (SnapdTask *task)
 {
+    /* Workaround to handle API change in SnapdProgressCallback */
+    if (SNAPD_IS_CHANGE (task))
+        return snapd_change_get_spawn_time (SNAPD_CHANGE (task));
+
     g_return_val_if_fail (SNAPD_IS_TASK (task), NULL);
     return task->spawn_time;
 }
@@ -186,11 +239,15 @@ snapd_task_get_spawn_time (SnapdTask *task)
  *
  * Get the time this taksk completed or %NULL if not yet completed.
  *
- * Returns: (allow-none): a #GDateTime or %NULL.
+ * Returns: (transfer none) (allow-none): a #GDateTime or %NULL.
  */
 GDateTime *
 snapd_task_get_ready_time (SnapdTask *task)
 {
+    /* Workaround to handle API change in SnapdProgressCallback */
+    if (SNAPD_IS_CHANGE (task))
+        return snapd_change_get_ready_time (SNAPD_CHANGE (task));
+
     g_return_val_if_fail (SNAPD_IS_TASK (task), NULL);
     return task->ready_time;
 }
@@ -218,7 +275,11 @@ snapd_task_set_property (GObject *object, guint prop_id, const GValue *value, GP
         task->status = g_strdup (g_value_get_string (value));
         break;
     case PROP_READY:
-        task->ready = g_value_get_boolean (value);
+        // Deprecated
+        break;
+    case PROP_PROGRESS_LABEL:
+        g_free (task->progress_label);
+        task->progress_label = g_strdup (g_value_get_string (value));
         break;
     case PROP_PROGRESS_DONE:
         task->progress_done = g_value_get_int64 (value);
@@ -260,12 +321,18 @@ snapd_task_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_STATUS:
         g_value_set_string (value, task->status);
         break;
+    case PROP_PROGRESS_LABEL:
+        g_value_set_string (value, task->progress_label);
+        break;
     case PROP_PROGRESS_DONE:
         g_value_set_int64 (value, task->progress_done);
         break;
     case PROP_PROGRESS_TOTAL:
         g_value_set_int64 (value, task->progress_total);
         break;
+    case PROP_READY:
+        g_value_set_boolean (value, FALSE);
+        break;
     case PROP_SPAWN_TIME:
         g_value_set_boxed (value, task->spawn_time);
         break;
@@ -286,7 +353,8 @@ snapd_task_finalize (GObject *object)
     g_clear_pointer (&task->id, g_free);
     g_clear_pointer (&task->kind, g_free);
     g_clear_pointer (&task->summary, g_free);
-    g_clear_pointer (&task->status, g_free);  
+    g_clear_pointer (&task->status, g_free);
+    g_clear_pointer (&task->progress_label, g_free);
     g_clear_pointer (&task->spawn_time, g_date_time_unref);
     g_clear_pointer (&task->ready_time, g_date_time_unref);  
 }
@@ -328,6 +396,13 @@ snapd_task_class_init (SnapdTaskClass *klass)
                                                           "Status of task",
                                                           NULL,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_PROGRESS_LABEL,
+                                     g_param_spec_string ("progress-label",
+                                                          "progress-label",
+                                                          "Label for progress",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_PROGRESS_DONE,
                                      g_param_spec_int64 ("progress-done",
@@ -348,7 +423,7 @@ snapd_task_class_init (SnapdTaskClass *klass)
                                                            "ready",
                                                            "TRUE when task complete",
                                                            FALSE,
-                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_DEPRECATED));
     g_object_class_install_property (gobject_class,
                                      PROP_SPAWN_TIME,
                                      g_param_spec_boxed ("spawn-time",
